.. title:: Welcome to createllm

Welcome to createllm
=====================

.. image:: https://img.shields.io/pypi/v/createllm.svg
    :target: https://pypi.python.org/pypi/createllm
    :alt: PyPI version

**A Python package that enables users to create and train their own Language Learning Models (LLMs) from scratch using custom datasets. This package provides a simplified approach to building, training, and deploying custom language models tailored to specific domains or use cases.**

Contents
--------

- `Installation <installation.md>`_
- `Usage <usage.md>`_
- `API Reference <createllm.md>`_
- `FAQ <faq.md>`_

License & Documentation
-----------------------

- Free software: MIT License
- Documentation: `<https://khushaljethava.github.io/createllm>`_

Features
--------

- TODO

